@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11713 2019-09-18 13:42:53Z Lavender $
+# $Id: __init__.py 11731 2019-10-02 16:41:15Z Lavender $
 #
 # Copyright (c) 2019 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-09-18 22:42:53 +0900 (週三, 18 九月 2019) $
-# $Revision: 11713 $
+# $Date: 2019-10-03 00:41:15 +0800 (週四, 03 十月 2019) $
+# $Revision: 11731 $
 #
 # Contributors:
 #  Bear (original author)
@@ -50,8 +50,8 @@ def attachSettings(settingsLocals, backends, preferred, config):
     ])
     
     DEFAULT_STATSD_SETTINGS = {
-        'STATSD_HOST': "statsd.nuwainfo.com",
-        "STATSD_PORT": 8125,
+        'STATSD_HOST': config.get("host", "statsd.nuwainfo.com"),
+        "STATSD_PORT": config.get("post", 8125),
     }
     
     update(settingsLocals, DEFAULT_STATSD_SETTINGS)
