@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11741 2019-10-08 07:46:25Z Lavender $
+# $Id: __init__.py 11751 2019-10-16 02:58:57Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-10-08 15:46:25 +0800 (週二, 08 十月 2019) $
-# $Revision: 11741 $
+# $Date: 2019-10-16 10:58:57 +0800 (週三, 16 十月 2019) $
+# $Revision: 11751 $
 
 import os
 import sys
@@ -433,6 +433,12 @@ def attachSettings(settingsDict, enablePaypal=False):
     }
     update(settingsDict, DJANGO_CKEDITOR_CONF)
     #=========================================================================
+    
+    #=========================================================================
+    # Oscar other settings OSCAR_SLUG_ALLOW_UNICODE
+    if DJANGO_VERSION >= 11100: # django >= 1.11
+        settingsDict['OSCAR_SLUG_ALLOW_UNICODE'] = True
+    #=========================================================================
 
     #=========================================================================
     # Django order status settings
@@ -801,8 +807,6 @@ def buildAPIForm(submission, request, apiName, extra={}):
             'Amt': int(total),
             'ItemDesc': itemName.replace(toBytes('#'), toBytes('|')),
             'LoginType': 0,
-            'CREDIT': 1,
-            #'UNIONPAY': 1,
         }
         
         if six.PY3:
@@ -825,7 +829,7 @@ def buildAPIForm(submission, request, apiName, extra={}):
     if apiName in [ECPAY, ALLPAY]:
         data = {
             'TotalAmount': int(total), 
-            'ChoosePayment': 'Credit', 
+            'ChoosePayment': 'ALL', 
             'MerchantTradeNo': merchantTradeNo, 
             'ItemName': itemName,
             'TradeDesc' : settings.OSCAR_SHOP_NAME, 
